pub struct CliArguments {
pub verbose: u8,
pub daemonize: bool,
pub config: Option<PathBuf>,
pub profile: Option<String>,
}Fields
verbose: u8Verbose mode (-v, -vv, -vvv)
daemonize: boolIf this flag is set, the daemon will start and fork itself into the background.
Beware: Closing the terminal won’t kill the daemon any longer. This should be avoided and rather be properly done using a service manager.
config: Option<PathBuf>If provided, Pueue only uses this config file.
This path can also be set via the $PUEUE_CONFIG_PATH environment variable. The commandline option overwrites the environment variable!
profile: Option<String>The name of the profile that should be loaded from your config file.